@@ -1,21 +1,27 @@
 # -*- coding: utf-8 -*-
 
 import os
+import datetime
+import time
 import tempfile
 import shutil
 from .randomutils import uuid4
 
 def mkdir(folder):
     os.makedirs(folder, exist_ok=True)
-
+    return os.path.exists(folder) and os.path.isdir(folder)
 
 def rm(filename):
-    if os.path.isfile(filename):
-        os.unlink(filename)
+    """Make sure a file or a directory has been deleted.
+    """
+    if os.path.exists(filename):
+        if os.path.isfile(filename):
+            os.unlink(filename)
+        else:
+            shutil.rmtree(filename, ignore_errors=True, onerror=None)
+        return not os.path.exists(filename)
     else:
-        shutil.rmtree(filename, ignore_errors=True, onerror=None)
-
-
+        return True
 
 def filecopy(src, dst, dst_is_a_folder=False):
     if dst_is_a_folder:
@@ -76,7 +82,9 @@ def rename(filepath, name):
 def move(src, dst):
     os.rename(src, dst)
 
-def file_content_replace(filename, original, replacement, binary=False, encoding="utf-8", recursive=True):
+def file_content_replace(filename, original, replacement, binary=False, encoding="utf-8", recursive=True, ignore_errors=True):
+    file_replaced = []
+    file_failed = {}
 
     def replace(filename, original, replacement, binary=False, encoding="utf-8"):
         content = readfile(filename, binary, encoding)
@@ -84,12 +92,34 @@ def file_content_replace(filename, original, replacement, binary=False, encoding
         write(filename, content, encoding)
 
     if os.path.isfile(filename):
-        replace(filename, original, replacement, binary, encoding)
-        return
+        try:
+            replace(filename, original, replacement, binary, encoding)
+            file_replaced.append(filename)
+        except Exception as error:
+            file_failed[path] = error
+            if not ignore_errors:
+                raise error
     else:
         folder = filename
         for root, dirs, files in os.walk(folder):
             for filename in files:
                 path = os.path.abspath(os.path.join(root, filename))
-                replace(path, original, replacement, binary, encoding)
-        return
+                try:
+                    replace(path, original, replacement, binary, encoding)
+                    file_replaced.append(path)
+                except Exception as error:
+                    file_failed[path] = error
+                    if not ignore_errors:
+                        raise error
+
+    return file_replaced, file_failed
+
+def touch(filename):
+    """Make sure a file exists
+    """
+    if os.path.exists(filename):
+        os.utime(filename, (time.time(), time.time()))
+    else:
+        with open(filename, "wb") as fobj:
+            pass
+    return os.stat(filename)
